/**
 * Copyright 2008 Bluestem Software LLC
 *   
 * All Rights Reserved. Bluestem Software LLC licenses this file
 * to you under the EOA Specification License Agreement [1]. You
 * may not use this file except in compliance with the License. You
 * may obtain a copy of the License at:
 *   
 * [1] http://alakai.org/licensing/specification-eoa-license.html
 *   
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.bluestemsoftware.specification.eoa;

import org.bluestemsoftware.specification.eoa.system.server.Server;

/**
 * Identifies a 'feature' dependency, i.e. the referencing artifact MAY depend upon the ability
 * to retrieve and utilize a <code>Feature</code> created by referenced factory in order to
 * implement its behavior.
 * <p>
 * Note that the rules used to distinguish a <code>FeatureDependency</code> from other
 * dependencies are an extension to the core specification.
 */
public interface FeatureDependency extends FactoryDependency {

    /**
     * Identifies feature implementation. Returns same value as {@link #getVersionlessRef()},
     * but sans extension. The format of implementation URI MUST be:
     * <p>
     * organizationID/artifactID
     * 
     * @return String
     */
    public String getExtensionImplementationRef();

    /**
     * Indicates whether or not referencing artifact requires <code>Feature</code> to
     * implement its behavior.
     * <p>
     * If flagged as required, and feature is not enabled, a compliant <code>Server</code>
     * MUST fail to start.
     * 
     * @return true if required, false if optional
     * @see Server#getFeature(String)
     */
    public boolean isRequired();

}
