/**
 * Copyright 2008 Bluestem Software LLC
 *   
 * All Rights Reserved. Bluestem Software LLC licenses this file
 * to you under the EOA Specification License Agreement [1]. You
 * may not use this file except in compliance with the License. You
 * may obtain a copy of the License at:
 *   
 * [1] http://alakai.org/licensing/specification-eoa-license.html
 *   
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.bluestemsoftware.specification.eoa;

import org.bluestemsoftware.specification.eoa.DeploymentClassLoader;

/**
 * Identifies a dependency 'scoped' to a deployment, i.e. it is not visible to other
 * deployments nor to <code>System</code>. A scoped dependency MUST be added by
 * <code>System</code> to deployment classpath, i.e. visible to {@link DeploymentClassLoader}.
 * <p>
 * Note that if dependency cannot be added to deployment classpath, e.g. the artifact cannot be
 * resolved, the deployment MUST fail to deploy.
 * <p>
 * The rules used to distinguish a <code>ScopedDependency</code> from other dependencies are
 * an extension to the core specification.
 */
public interface ScopedDependency extends Dependency {

    /**
     * Identifies 'trail' to root dependency which MAY be used for debugging.
     * 
     * @return
     */
    public String getDependencyTrail();
 
}
