/**
 * Copyright 2008 Bluestem Software LLC
 *   
 * All Rights Reserved. Bluestem Software LLC licenses this file
 * to you under the EOA Specification License Agreement [1]. You
 * may not use this file except in compliance with the License. You
 * may obtain a copy of the License at:
 *   
 * [1] http://alakai.org/licensing/specification-eoa-license.html
 *   
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.bluestemsoftware.specification.eoa.component.application.rt;

import java.util.Collection;

import javax.xml.namespace.QName;

import org.bluestemsoftware.specification.eoa.component.application.Application;
import org.bluestemsoftware.specification.eoa.component.rt.RootComponentRT.SingletonRT;
import org.bluestemsoftware.specification.eoa.ext.RootExtension;

/**
 * Models an <code>Application</code> component at 'compile-time' (abstract), i.e. as
 * compared to 'runtime' (concrete) which is modeled by an instance of {@link EngineRT}.
 * <p>
 * Note that type specific methods may be accessed by casting <code>ApplicationRT</code> to a
 * well-known implementation as indicated by {@link #getExtensionType()}. Note that a
 * deployment MUST NOT contain more than one runtime application definition.
 */
public interface ApplicationRT extends RootExtension, SingletonRT<Application> {

    /*
     * (non-Javadoc)
     * 
     * SPI
     */
    public interface Provider extends RootExtension.Provider {
    }

    /**
     * Gets <code>ApplicationReference</code> by name.
     * 
     * @param applicationName
     * @return ApplicationReference or <code>null</code> if undefined.
     */
    public ApplicationReference getApplicationReference(QName applicationName);

    /**
     * Returns all referenced 'partner' <code>Application</code> components.
     * 
     * @return Collection of <code>ApplicationReference</code> components or empty Collection
     *         if none defined.
     */
    public Collection<ApplicationReference> getApplicationReferences();

}