/**
 * Copyright 2008 Bluestem Software LLC
 *   
 * All Rights Reserved. Bluestem Software LLC licenses this file
 * to you under the EOA Specification License Agreement [1]. You
 * may not use this file except in compliance with the License. You
 * may obtain a copy of the License at:
 *   
 * [1] http://alakai.org/licensing/specification-eoa-license.html
 *   
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.bluestemsoftware.specification.eoa.component.binding;

import javax.xml.namespace.QName;

import org.bluestemsoftware.specification.eoa.DeploymentException;
import org.bluestemsoftware.specification.eoa.component.ComponentReference;
import org.bluestemsoftware.specification.eoa.component.FragmentIdentifier;
import org.bluestemsoftware.specification.eoa.component.NestedComponent;
import org.bluestemsoftware.specification.eoa.component.FragmentIdentifier.Scheme;
import org.bluestemsoftware.specification.eoa.component.RootComponent.ComponentName;
import org.bluestemsoftware.specification.eoa.component.RootComponent.ComponentType;
import org.bluestemsoftware.specification.eoa.component.intrface.Interface;

public class InterfaceReference extends NestedComponent<Binding, Binding> implements ComponentReference<Interface> {

    protected ComponentName interfaceName;
    protected Interface intrface;

    public InterfaceReference(ComponentName interfaceName) {
        if (interfaceName == null) {
            throw new IllegalArgumentException("interfaceName null");
        } else {
            this.interfaceName = interfaceName;
        }
    }

    /*
     * (non-Javadoc)
     * @see org.bluestemsoftware.specification.eoa.component.ComponentReference#getReferencedComponentName()
     */
    public ComponentName getReferencedComponentName() {
        return interfaceName;
    }

    /*
     * (non-Javadoc)
     * @see org.bluestemsoftware.specification.eoa.component.ComponentReference#getReferencedComponentType()
     */
    public ComponentType getReferencedComponentType() {
        return ComponentType.INTERFACE;
    }
    
    /*
     * (non-Javadoc)
     * @see org.bluestemsoftware.specification.eoa.component.ComponentReference#getReferencedComponentClass()
     */
    public Class<Interface> getReferencedComponentClass() {
        return Interface.class;
    }

    /*
     * (non-Javadoc)
     * @see org.bluestemsoftware.specification.eoa.component.ComponentReference#getReferencedComponent()
     */
    public Interface getReferencedComponent() {
        return intrface;
    }

    final void establishReference() throws DeploymentException {
        if (intrface != null) {
            return;
        }
        if (parent == null) {
            throw new IllegalStateException("parent null");
        }
        intrface = getRootComponent().getComponentContext().findReferencedComponent(this);
        if (intrface == null) {
            throw new DeploymentException("ComponentReference '"
                    + getFragmentIdentifier()
                    + "' is invalid. Referenced Interface "
                    + interfaceName
                    + " is undefined.");
        }
    }

    /*
     * (non-Javadoc)
     * @see org.bluestemsoftware.specification.eoa.component.Component#getFragmentIdentifier()
     */
    public FragmentIdentifier getFragmentIdentifier() {
        if (fragmentIdentifier == null) {
            QName rootName = getRootComponent().getName();
            String pointerPart = parent.getFragmentIdentifier().getPointerPart();
            fragmentIdentifier = new FragmentIdentifier(rootName.getNamespaceURI(), Scheme.EOA,
                    "bindingInterfaceReference", pointerPart.toString());
        }
        return fragmentIdentifier;
    }

    void setParent(Binding parent) {
        this.parent = parent;
    }

    // *********************** Identity Methods ************************************

    @Override
    public String toString() {
        StringBuffer sb = new StringBuffer();
        sb.append("interfaceName: ");
        sb.append(interfaceName);
        return sb.toString();
    }

    @Override
    public int hashCode() {
        return hashCode(interfaceName);
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == this) {
            return true;
        }

        if (!(obj instanceof InterfaceReference)) {
            return false;
        }

        if ((interfaceName == ((InterfaceReference)obj).interfaceName || (interfaceName != null && interfaceName
                .equals(((InterfaceReference)obj).interfaceName)))) {
            return true;
        }

        return false;
    }

    private int hashCode(Object object) {
        return (object == null ? 0 : object.hashCode());
    }

}
