/**
 * Copyright 2008 Bluestem Software LLC
 *   
 * All Rights Reserved. Bluestem Software LLC licenses this file
 * to you under the EOA Specification License Agreement [1]. You
 * may not use this file except in compliance with the License. You
 * may obtain a copy of the License at:
 *   
 * [1] http://alakai.org/licensing/specification-eoa-license.html
 *   
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.bluestemsoftware.specification.eoa.component.binding.rt;

import java.util.List;

import javax.xml.namespace.QName;

import org.bluestemsoftware.specification.eoa.component.application.rt.ApplicationRT;
import org.bluestemsoftware.specification.eoa.component.intrface.rt.SystemFault;
import org.bluestemsoftware.specification.eoa.component.message.rt.Content;

/**
 * Encapsulates information related to an error which was encountered within binding layer
 * while processing a partner response after the response was accepted for processing, e.g.
 * protocol specific headers defined on response were not understood, response was not
 * consistent with wsdl description, response action not declared, a binding module failed to
 * process response, a programming error, etc ...
 * 
 * @see SystemFault#valueOf(ApplicationRT, AcceptedResponseError)
 */
public final class AcceptedResponseError extends BindingFaultRT {

    private static final long serialVersionUID = 1L;

    private List<Content> detail;

    /**
     * Constructor
     * 
     * @param faultName
     * @param faultReason
     * @param detail
     *        Detail related to fault, e.g. child elements of SOAP fault detail element if
     *        partner response was a fault response or payload element if response was a normal
     *        response.
     */
    public AcceptedResponseError(QName faultName, String faultReason, List<Content> detail) {
        super(faultName, faultReason);
        this.detail = detail;
    }

    /*
     * (non-Javadoc)
     * @see org.bluestemsoftware.specification.eoa.component.binding.rt.BindingFaultRT#appendFaultDetail(org.bluestemsoftware.specification.eoa.component.message.rt.Content)
     */
    @Override
    public void appendFaultDetail(Content faultEnvelope) {
        throw new UnsupportedOperationException();
    }

    /*
     * (non-Javadoc)
     * @see org.bluestemsoftware.specification.eoa.component.binding.rt.BindingFaultRT#getAction()
     */
    @Override
    public String getAction() {
        throw new UnsupportedOperationException();
    }

    /**
     * Gets detail related to fault, e.g. child elements of SOAP fault detail element if
     * partner response was a fault response or payload element if response was a normal
     * response.
     * 
     * @return
     */
    public List<Content> getDetail() {
        return detail;
    }

}
