/**
 * Copyright 2008 Bluestem Software LLC
 *   
 * All Rights Reserved. Bluestem Software LLC licenses this file
 * to you under the EOA Specification License Agreement [1]. You
 * may not use this file except in compliance with the License. You
 * may obtain a copy of the License at:
 *   
 * [1] http://alakai.org/licensing/specification-eoa-license.html
 *   
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.bluestemsoftware.specification.eoa.component.intrface;

import org.bluestemsoftware.specification.eoa.component.ComponentDeployment;
import org.bluestemsoftware.specification.eoa.component.RootComponent.ComponentName;
import org.bluestemsoftware.specification.eoa.component.RootComponent.ComponentType;
import org.bluestemsoftware.specification.eoa.component.application.rt.ApplicationRT;
import org.bluestemsoftware.specification.eoa.component.intrface.InterfaceAction.RequestAction;
import org.bluestemsoftware.specification.eoa.component.intrface.rt.ActionContext;
import org.bluestemsoftware.specification.eoa.component.intrface.rt.MessageContext;
import org.bluestemsoftware.specification.eoa.component.intrface.rt.ActionContext.MessageModules;
import org.bluestemsoftware.specification.eoa.component.message.InterfaceMessage;
import org.bluestemsoftware.specification.eoa.component.message.InterfaceMessage.AnyMessage;
import org.bluestemsoftware.specification.eoa.component.message.rt.Message;
import org.bluestemsoftware.specification.eoa.component.policy.rt.ElementPolicy;
import org.bluestemsoftware.specification.eoa.ext.feature.ws.addressing.WSAMessageModule;
import org.bluestemsoftware.specification.eoa.system.SystemContext;

/**
 * References a 'request' message, i.e. an action whose direction is 'In'.
 */
public final class RequestMessageReference extends InterfaceMessageReference implements RequestAction {

    public RequestMessageReference(ComponentName interfaceMessageName, String action, Direction direction,
            ContentModel contentModel, ElementPolicy elementPolicy) {
        super(interfaceMessageName, action, direction, contentModel, elementPolicy);
    }

    /*
     * (non-Javadoc)
     * @see org.bluestemsoftware.specification.eoa.component.intrface.InterfaceAction.RequestAction#createAction(org.bluestemsoftware.specification.eoa.component.application.rt.ApplicationRT)
     */
    public ActionContext createAction(ApplicationRT application) {
        MessageModules mm = new MessageModules(new WSAMessageModule(action));
        InterfaceMessage am = getReferencedComponent();
        ComponentDeployment deployment = application.getComponentContext().getDeployment();
        Message m = null;
        if (am == null) {
            // def imported via wsdl 2.0. content model will never be null. note
            // that if model is #other, the serialization will be handled by
            // the binding, i.e. the payload will always be transported within
            // the application layer as DOM, so .. return any message instance
            if (contentModel == ContentModel.NONE) {
                return new MessageContext(mm, m);
            } else if (contentModel == ContentModel.ANY || contentModel == ContentModel.OTHER) {
                am = SystemContext.getContext().getSystem().getMessage(AnyMessage.NAME);
            } else {
                throw new IllegalStateException("Abstract message undefined.");
            }
        }
        // note that if message definition was imported via wsdl 1.1, an empty
        // message is modeled as a message with no parts and content model is
        // null. according to ActionContext api, if content model is not #none,
        // a message instance is returned (but won't be useable without parts)
        m = (Message)deployment.getProvider(ComponentType.MESSAGE, am.getName());
        if (m == null) {
            m = ((Message)am.getRuntimeProvider()).cloneDefinition();
        } else {
            m = m.cloneDefinition();
        }
        return new MessageContext(mm, m);
    }

}
