/**
 * Copyright 2008 Bluestem Software LLC
 *   
 * All Rights Reserved. Bluestem Software LLC licenses this file
 * to you under the EOA Specification License Agreement [1]. You
 * may not use this file except in compliance with the License. You
 * may obtain a copy of the License at:
 *   
 * [1] http://alakai.org/licensing/specification-eoa-license.html
 *   
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.bluestemsoftware.specification.eoa.component.intrface.rt;

import org.bluestemsoftware.specification.eoa.component.intrface.InterfaceFaultReference;

/**
 * Defines context within which an {@link ApplicationFault} occurred, which, if declared,
 * models a runtime instance of {@link InterfaceFaultReference}. If undeclared, action is the
 * implied, 'built-in' action {@link SystemFault#ACTION}.
 */

public class FaultContext extends ActionContext {

    private static final long serialVersionUID = 1L;

    protected ApplicationFault applicationFault;

    /**
     * Constructs a <code>FaultContext</code> object.
     * 
     * @param messageModules
     * @param message
     *        runtime message instance.
     * @param faultName
     *        Identifies fault which initiated action. Note that if fault is undeclared, fault
     *        MUST be {@link SystemFault}.
     */
    public FaultContext(MessageModules messageModules, ApplicationFault applicationFault) {
        super(messageModules, applicationFault == null ? null : applicationFault.toMessage());
        this.applicationFault = applicationFault;
    }

    /**
     * Gets fault which initiated action.
     * 
     * @return ApplicationFault
     */
    public final ApplicationFault getFault() {
        return applicationFault;
    }

}