/**
 * Copyright 2008 Bluestem Software LLC
 *   
 * All Rights Reserved. Bluestem Software LLC licenses this file
 * to you under the EOA Specification License Agreement [1]. You
 * may not use this file except in compliance with the License. You
 * may obtain a copy of the License at:
 *   
 * [1] http://alakai.org/licensing/specification-eoa-license.html
 *   
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.bluestemsoftware.specification.eoa.component.message.rt;

import javax.xml.stream.XMLStreamReader;

import org.w3c.dom.Element;
import org.w3c.dom.ls.LSSerializer;

/**
 * Models message 'content'. Content MAY represent all or part of a runtime abstract message
 * instance or it MAY represent all or part of a runtime, concrete message instance, e.g. a
 * SOAP message.
 */
public interface Content extends Element {

    /**
     * Gets underlying reader.
     * 
     * @return reader
     * @throws UnsupportedOperationException
     *         if reader not available
     */
    public XMLStreamReader getReader();

    /**
     * Gets content factory, i.e. reference to factory that created content.
     * 
     * @return
     */
    public ContentFactory getFactory();

    /**
     * Convenience method which serializes message as unformatted xml using the 'UTF-8' charset
     * encoding and the default serialization, i.e. {@link ContentSerializationXML}.
     * <p>
     * Note, if control over formatting, encoding, etc ... is required use {@link LSSerializer}
     * instead.
     * 
     * @return String
     */
    public String toXML();

    /**
     * Serializes content using indicated serialization and default character set encoding
     * UTF-8.
     * 
     * @param serialization
     * @return String
     */
    public String serializeContent(ContentSerialization serialization);

    /**
     * Serializes content using indicated serialization and character set encoding.
     * 
     * @param serialization
     * @param encoding
     * @return String
     */
    public String serializeContent(ContentSerialization serialization, String encoding);

}
