/**
 * Copyright 2008 Bluestem Software LLC
 *   
 * All Rights Reserved. Bluestem Software LLC licenses this file
 * to you under the EOA Specification License Agreement [1]. You
 * may not use this file except in compliance with the License. You
 * may obtain a copy of the License at:
 *   
 * [1] http://alakai.org/licensing/specification-eoa-license.html
 *   
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.bluestemsoftware.specification.eoa.component.policy.rt;

import java.util.Set;

import org.bluestemsoftware.specification.eoa.system.server.ModulableFeature;

/**
 * Thrown by an instanceof {@link ModulableFeature} to indicate that it is unable to comply
 * with <code>EffectivePolicy</code>.
 */

public class UnsupportedPolicyException extends Exception {

    private static final long serialVersionUID = 1L;

    private EffectivePolicy effectivePolicy;
    private Set<PolicyAssertion> unsupportedAssertions;
    
    /**
     * @param errorMessage which describes why policy is unsupported.
     */
    public UnsupportedPolicyException(String message) {
        super(message);
    }
    
    /**
     * Constructs and instance of <code>UnsupportablePolicyException</code>.
     * @param effectivePolicy which wraps the unsupported expression.
     * @param errorMessage which describes why effective expression is unsupported.
     */
    public UnsupportedPolicyException(EffectivePolicy effectivePolicy, String errorMessage) {
        super(errorMessage);
        if (effectivePolicy == null) {
            throw new IllegalArgumentException("effectivePolicy null");
        } else {
            this.effectivePolicy = effectivePolicy;
        }
        if (errorMessage == null) {
            throw new IllegalArgumentException("errorMessage null");
        }
    }

    /**
     * Constructs and instance of <code>UnsupportablePolicyException</code>.
     * @param effectivePolicy which wraps the unsupported expression.
     * @param unsupportedAssertions or <code>null</code> if undefined
     */
    public UnsupportedPolicyException(EffectivePolicy effectivePolicy, Set<PolicyAssertion> unsupportedAssertions) {
        if (effectivePolicy == null) {
            throw new IllegalArgumentException("effectivePolicy null");
        } else {
            this.effectivePolicy = effectivePolicy;
        }
        if (unsupportedAssertions == null) {
            throw new IllegalArgumentException("unsupportedAssertions null");
        } else {
            this.unsupportedAssertions = unsupportedAssertions;
        }
    }

    public EffectivePolicy getEffectivePolicy() {
        return effectivePolicy;
    }
    
    public Set<PolicyAssertion> getUnsupportedAssertions() {
        return unsupportedAssertions;
    }

}
