/**
 * Copyright 2008 Bluestem Software LLC
 *   
 * All Rights Reserved. Bluestem Software LLC licenses this file
 * to you under the EOA Specification License Agreement [1]. You
 * may not use this file except in compliance with the License. You
 * may obtain a copy of the License at:
 *   
 * [1] http://alakai.org/licensing/specification-eoa-license.html
 *   
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.bluestemsoftware.specification.eoa.component.rt;

import java.util.Set;

import javax.xml.transform.dom.DOMSource;

import org.bluestemsoftware.specification.eoa.DeploymentException;
import org.bluestemsoftware.specification.eoa.component.ComponentContext;
import org.bluestemsoftware.specification.eoa.ext.ExtensionFactory;

/**
 * Models a specific type of <code>ExtensionFactory</code>, i.e. a factory which is used to
 * parse runtime provider definition(s) manifested within provided source.
 * <p>
 * Note that ref URI which identifies <code>ExtensionFactory</code>, i.e. value retrieved
 * via {@link ExtensionFactory#getExtensionType()} is used by deployer to match provider
 * definition namespace with an instance of <code>ProviderReader</code>.
 */

public interface ProviderReader <T extends RootComponentRT>{

    /**
     * Reads a <code>Component</code> provider definition from provided source and any
     * de-referenceable provider definitions which MAY be referenced by target component.
     * 
     * @param componentContext
     *        Which defines context within which definitions are deployed and which MUST be
     *        used by implementations to resolve entities which MAY be referenced by targeted
     *        provider definition.
     * @param source
     *        Source within which target provider definition is manifested.
     * 
     * @throws DeploymentException
     *         If an error occurs reading provider definition.
     */
    public Set<T> readProviders(ComponentContext componentContext, DOMSource source) throws DeploymentException;

}
