/**
 * Copyright 2008 Bluestem Software LLC
 *   
 * All Rights Reserved. Bluestem Software LLC licenses this file
 * to you under the EOA Specification License Agreement [1]. You
 * may not use this file except in compliance with the License. You
 * may obtain a copy of the License at:
 *   
 * [1] http://alakai.org/licensing/specification-eoa-license.html
 *   
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.bluestemsoftware.specification.eoa.component.types;

import java.util.Map;

import javax.xml.namespace.QName;

import org.bluestemsoftware.specification.eoa.DeploymentException;
import org.bluestemsoftware.specification.eoa.component.message.MessagePart;
import org.bluestemsoftware.specification.eoa.ext.schema.SchemaFactory;

/**
 * Models a specific type of <code>SchemaComponent</code>, i.e. a global element
 * declaration.
 * <p>
 * Note that concrete implementations of {@link SchemaFactory} MUST create a WSDL 2.0 style,
 * abstract message definition for each global element declaration parsed by factory where
 * <code>InterfaceMessage</code> contains a single part named {@link MessagePart#PAYLOAD}
 * which is typed as an element. Payload type serves a proxy for abstract message name.
 */

public class ElementDeclaration extends SchemaComponent {

    private boolean isMessagePayload;

    public ElementDeclaration(String name, Map<QName, SchemaFragment> fragments, boolean isMessagePayload) {
        super(name, fragments);
        this.isMessagePayload = isMessagePayload;
    }

    /*
     * (non-Javadoc)
     * @see org.bluestemsoftware.specification.eoa.component.types.SchemaComponent#getType()
     */
    public Type getType() {
        return Type.ELEMENT_DECLARATION;
    }

    void validate() throws DeploymentException {
        super.validate();
    }

    /**
     * Indicates if element declaration defines payload of an abstract message. Note that
     * compliant implementations of <code>SchemaFactory</code> MUST default this value to
     * true unless explicitly overridden, e.g. via an xml schema annotation.
     * <p>
     * If true, and <code>ElementDeclaration</code> was not sourced from a WSDL 1.1 document,
     * a compliant <code>SchemaFactory</code> MUST create a WSDL 2.0 style abstract message
     * definition which contains a single part named {@link MessagePart#PAYLOAD} and which is
     * typed using this element declaration. The qualified name of element MUST be used as a
     * proxy for abstract message name. The message component MUST be added to same deployment
     * as parent schema of element decl.
     * 
     * @return true if element decl defines message payload, false if not.
     */
    public boolean isMessagePayload() {
        return isMessagePayload;
    }

}