/**
 * Copyright 2008 Bluestem Software LLC
 *   
 * All Rights Reserved. Bluestem Software LLC licenses this file
 * to you under the EOA Specification License Agreement [1]. You
 * may not use this file except in compliance with the License. You
 * may obtain a copy of the License at:
 *   
 * [1] http://alakai.org/licensing/specification-eoa-license.html
 *   
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.bluestemsoftware.specification.eoa.component.types;

import java.util.Map;

import javax.xml.namespace.QName;

import org.bluestemsoftware.specification.eoa.DeploymentException;

/**
 * Models a schema Type definition, i.e. a complex type definition or a simple type definition.
 */

public final class TypeDefinition extends SchemaComponent {

    boolean isSimpleType;
    
    public TypeDefinition(String name, Map<QName, SchemaFragment> fragments, boolean isSimpleType) {
        super(name, fragments);
        this.isSimpleType = isSimpleType;
    }

    public Type getType() {
        return Type.TYPE_DEFINITION;
    }

    /**
     * Convenience method which indicates whether definition is a simple schema type or complex
     * schema type.
     * @return true if simple, false if complex
     */
    public boolean isSimpleType() {
        return isSimpleType;
    }

    void validate() throws DeploymentException {
        super.validate();
    }
    
}