/**
 * Copyright 2008 Bluestem Software LLC
 *   
 * All Rights Reserved. Bluestem Software LLC licenses this file
 * to you under the EOA Specification License Agreement [1]. You
 * may not use this file except in compliance with the License. You
 * may obtain a copy of the License at:
 *   
 * [1] http://alakai.org/licensing/specification-eoa-license.html
 *   
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.bluestemsoftware.specification.eoa.ext;

import org.bluestemsoftware.specification.eoa.DeploymentClassLoader;

/**
 * Models an object whose runtime behavior is defined as an 'extension' to the core EOA
 * specification.
 */
public interface Extension {

    /**
     * Interface which MUST be extended by concrete instances of <code>Extension</code> and
     * which MUST be implemented by <code>Extension</code> providers.
     * <p>
     * Note that concrete instances of <code>Extension</code> MUST invoke provider methods
     * within context of {@link DeploymentClassLoader} defined on <code>ExtensionFactory</code>
     * which created <code>Extension</code>.
     */
    public interface Provider {

        /**
         * Sets reference to <code>Extension</code> instance which 'consumes' provider
         * instance.
         * 
         * @param consumer
         */
        public void spi_setConsumer(Extension consumer);

    }

    /**
     * Gets <code>Extension</code> service provider instance 'consumed' by this
     * <code>Extension</code> instance.
     * @return
     */
    public Provider getExtensionProvider();

    /**
     * Gets factory that created <code>Extension</code>. Note that
     * <code>ExtensionFactory</code> which creates a {@link RootExtension} and
     * <code>ExtensionFactory</code> which creates instances of {@link NestedExtension} which
     * MAY be nested within <code>RootExtension</code> MUST be the same factory.
     * 
     * @return factory
     */
    public ExtensionFactory getExtensionFactory();

}