/**
 * Copyright 2008 Bluestem Software LLC
 *   
 * All Rights Reserved. Bluestem Software LLC licenses this file
 * to you under the EOA Specification License Agreement [1]. You
 * may not use this file except in compliance with the License. You
 * may obtain a copy of the License at:
 *   
 * [1] http://alakai.org/licensing/specification-eoa-license.html
 *   
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.bluestemsoftware.specification.eoa.ext;

import org.bluestemsoftware.specification.eoa.ext.RootExtension.AbstractRootExtension;


/**
 * Identifies a specific type of <code>Extension</code>, i.e. an <code>Extension</code>
 * whose 'life cycle' is managed by <code>System</code>.
 */
public abstract class ManageableExtension extends AbstractRootExtension {

    
    public interface Provider extends RootExtension.Provider {
    }
    
    public ManageableExtension(ExtensionFactory factory, Provider provider) {
        super(factory, provider);
    }

    /**
     * Invoked by <code>System</code> before <code>Extension</code> is used. Allows
     * <code>Extension</code> to initialize resources which MAY be required to implement
     * extension behavior.
     * 
     * @throws ExtensionException
     *         if an error occurs during initialization
     */
    public abstract void init() throws ExtensionException;

    /**
     * Invoked by <code>System</code> when <code>Extension</code> is no longer required.
     * Allows <code>Extension</code> to destroy resources which MAY have been created within
     * init method.
     */
    public abstract void destroy();

}
