/**
 * Copyright 2008 Bluestem Software LLC
 *   
 * All Rights Reserved. Bluestem Software LLC licenses this file
 * to you under the EOA Specification License Agreement [1]. You
 * may not use this file except in compliance with the License. You
 * may obtain a copy of the License at:
 *   
 * [1] http://alakai.org/licensing/specification-eoa-license.html
 *   
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.bluestemsoftware.specification.eoa.ext.container;

import javax.xml.transform.dom.DOMSource;

import org.bluestemsoftware.specification.eoa.ext.ExtensionFactory;
import org.bluestemsoftware.specification.eoa.system.container.Container;
import org.w3c.dom.Node;

/**
 * A type specific factory for {@link Container} components. Note the means by which a type
 * specific instance of this class is discovered and used to create <code>Container</code>
 * component is outside the scope of this specification.
 */

public abstract class ContainerFactory extends ExtensionFactory {

    /*
     * (non-Javadoc)
     * 
     * SPI
     */
    public interface Provider extends ExtensionFactory.Provider {
    }

    /*
     * (non-Javadoc)
     * @see org.bluestemsoftware.specification.eoa.ext.ExtensionFactory#getType()
     */
    public final Type getType() {
        return Type.CONTAINER;
    }

    /**
     * Parses component definition, i.e. an <code>Element</code> instance, into a container
     * instance.
     * 
     * @param domSource
     *        which MUST contain a <code>Node</code> of type {@link Node#ELEMENT_NODE} and
     *        whose namespace URI MUST match value returned via {@link #getExtensionType()}.
     * @return Container
     */
    public abstract Container createContainer(DOMSource domSource) throws ContainerException;

}