/**
 * Copyright 2008 Bluestem Software LLC
 *   
 * All Rights Reserved. Bluestem Software LLC licenses this file
 * to you under the EOA Specification License Agreement [1]. You
 * may not use this file except in compliance with the License. You
 * may obtain a copy of the License at:
 *   
 * [1] http://alakai.org/licensing/specification-eoa-license.html
 *   
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.bluestemsoftware.specification.eoa.system.server;

import java.util.Set;

import org.bluestemsoftware.specification.eoa.component.engine.rt.FeatureModule;
import org.bluestemsoftware.specification.eoa.ext.Extension;

/**
 * Identifies a specific type of <code>Feature</code>, i.e. a feature whose behavior is
 * implemented on a per message basis via one or more {@link FeatureModule} instances.
 * <p>
 * Note that {@link FeatureModule} instances MAY rely upon a common configuration, i.e.
 * configuration provided by <code>ModulableFeature</code> implementation.
 */
public interface ModulableFeature {

    /**
     * Identifies policy vocabulary namespaces. The ws-policy specification defines a
     * vocabulary as a set of domain specific assertion types, all of which share a common
     * namespace. Policy 'vocabulary' is used to enable/constrain feature module behavior.
     * <p>
     * Note that unless features are all instances of {@link BindingFeature} each of which
     * implement a different binding type, a compliant <code>Server</code> MUST insure that
     * <code>ModulableFeature</code> instances do not share a common policy vocabulary.
     * <p>
     * Note that policy vocabulary namespace MAY be used for feature versioning, i.e. to
     * identify supported version(s) of underlying specification which defines feature
     * behavior. A provider MAY choose to support more than one version. Consequently,
     * <code>Feature</code> type, as identified by {@link Extension#getExtensionType()}
     * SHOULD be version agnostic.
     * 
     * @return Set of vocabulary namespace URIs
     */
    public Set<String> getPolicyVocabularyNamespaces();
    
    /**
     * Invoked by <code>System</code> when <code>FeatureModule</code> is no longer
     * used.
     * 
     * @param bindingModule
     */
    public void destroyFeatureModule(FeatureModule featureModule);


}
